==> openshift-model-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/APIServerListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface APIServerListFluent<A extends APIServerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,APIServer item);
    public A setToItems(int index,APIServer item);
    public A addToItems(APIServer... items);
    public A addAllToItems(Collection<APIServer> items);
    public A removeFromItems(APIServer... items);
    public A removeAllFromItems(Collection<APIServer> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<APIServerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<APIServer> getItems();
    public List<APIServer> buildItems();
    public APIServer buildItem(int index);
    public APIServer buildFirstItem();
    public APIServer buildLastItem();
    public APIServer buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServerBuilder> predicate);
    public A withItems(List<APIServer> items);
    public A withItems(APIServer... items);
    public Boolean hasItems();
    public APIServerListFluent.ItemsNested<A> addNewItem();
    public APIServerListFluent.ItemsNested<A> addNewItemLike(APIServer item);
    public APIServerListFluent.ItemsNested<A> setNewItemLike(int index,APIServer item);
    public APIServerListFluent.ItemsNested<A> editItem(int index);
    public APIServerListFluent.ItemsNested<A> editFirstItem();
    public APIServerListFluent.ItemsNested<A> editLastItem();
    public APIServerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,APIServerFluent<APIServerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-5.0.3-sources.jar: annotations/io/fabric8/openshift/api/model/APIServerListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface APIServerListFluent<A extends APIServerListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,APIServer item);
    public A setToItems(int index,APIServer item);
    public A addToItems(APIServer... items);
    public A addAllToItems(Collection<APIServer> items);
    public A removeFromItems(APIServer... items);
    public A removeAllFromItems(Collection<APIServer> items);
    public A removeMatchingFromItems(Predicate<APIServerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<APIServer> getItems();
    public List<APIServer> buildItems();
    public APIServer buildItem(int index);
    public APIServer buildFirstItem();
    public APIServer buildLastItem();
    public APIServer buildMatchingItem(Predicate<APIServerBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<APIServerBuilder> predicate);
    public A withItems(List<APIServer> items);
    public A withItems(APIServer... items);
    public Boolean hasItems();
    public APIServerListFluent.ItemsNested<A> addNewItem();
    public APIServerListFluent.ItemsNested<A> addNewItemLike(APIServer item);
    public APIServerListFluent.ItemsNested<A> setNewItemLike(int index,APIServer item);
    public APIServerListFluent.ItemsNested<A> editItem(int index);
    public APIServerListFluent.ItemsNested<A> editFirstItem();
    public APIServerListFluent.ItemsNested<A> editLastItem();
    public APIServerListFluent.ItemsNested<A> editMatchingItem(Predicate<APIServerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,APIServerFluent<APIServerListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
